Class: Flowbite::Input::Email
- Inherits:
-
Input
- Object
- Input
- Flowbite::Input::Email
- Defined in:
- app/components/flowbite/input/email.rb
Instance Method Summary collapse
-
#input_field_type ⇒ Object
Returns the name of the method used to generate HTML for the input field.
Instance Method Details
#input_field_type ⇒ Object
Returns the name of the method used to generate HTML for the input field
7 8 9 |
# File 'app/components/flowbite/input/email.rb', line 7 def input_field_type :email_field end |